@@ -444,7 +444,9 @@ link_connection_from_fd_T (LinkConnection         *cnx,
 
 	switch (cnx->proto->family) {
 	case AF_INET:
+#ifdef AF_INET6
 	case AF_INET6:
+#endif
 		if (_link_timeout && !cnx->timeout_msec) /* this should'nt happen twice but I'm always paranoid... */
 			cnx->timeout_msec = _link_timeout;
 		break;
@@ -1267,11 +1269,9 @@ link_connection_finalize (GObject *obj)
 
 	if (cnx->timeout_mutex)
 		g_mutex_free (cnx->timeout_mutex);
-
-	if (cnx->timeout_source_id)
+	if (cnx->timeout_source_id) 
 		link_io_thread_remove_timeout (cnx->timeout_source_id);
 
-
 #ifdef G_ENABLE_DEBUG
 	g_assert (g_list_find(cnx_list, cnx) == NULL);
 #endif
@@ -1292,6 +1292,7 @@ link_connection_init (LinkConnection *cnx)
 	cnx->timeout_msec = 0;
 	cnx->timeout_source_id = 0;
 	cnx->timeout_status = LINK_TIMEOUT_UNKNOWN;
+	cnx->tdata = NULL; 
 
 #ifdef CONNECTION_DEBUG
 	cnx->priv->total_read_bytes = 0;
